@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.2-3
+# Application Name - Health Check V0.5.2-4
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -219,6 +219,13 @@ class Ui_MainWindow(object):
         self.pushButton_led.setText("Test LED's")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_led, QtCore.SIGNAL('clicked()'), self.updateLED)
+
+        self.pushButton_snd1 = QtGui.QPushButton(self.tab_4)
+        self.pushButton_snd1.setGeometry(QtCore.QRect(10, 40, 391, 71))
+        self.pushButton_snd1.setObjectName("pushButton_snd1")
+        self.pushButton_snd1.setText("Test Sound")
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        QtCore.QObject.connect(self.pushButton_snd1, QtCore.SIGNAL('clicked()'), self.updatesound)
     
         self.tabWidget.addTab(self.tab_4, "")
 
@@ -231,7 +238,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.2-3 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.2-4 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -246,7 +253,8 @@ class Ui_MainWindow(object):
         self.menubar.setObjectName("menubar")
         MainWindow.setMenuBar(self.menubar)
         # Draw the Status bar
-
+        self.addemptylist1()
+        self.addemptylist2()
         # Run the translate UI - Added by QT Designer - i have removed alot of setText's and placed them above.
         self.retranslateUi(MainWindow)
         #self.updateTab1()
@@ -256,7 +264,31 @@ class Ui_MainWindow(object):
         QtCore.QMetaObject.connectSlotsByName(MainWindow)
   
 
-    
+    def addemptylist1(self):
+        self.listWidget.clear()
+        self.listWidget.addItem("Firmware Version")
+        self.listWidget.addItem("Processor Information")
+        self.listWidget.addItem("N900 Board")
+        self.listWidget.addItem("System Locale")   
+        self.listWidget.addItem("Boot Count")
+        self.listWidget.addItem("FM Trans Strength")
+        self.listWidget.addItem("System Uptime")
+        self.listWidget.addItem("Battery")
+        self.listWidget.addItem("Accelerometer")
+        self.listWidget.addItem("MyDocs")
+        self.listWidget.addItem("Rootfs Free")
+        self.listWidget.sortItems()
+
+    def addemptylist2(self):
+        self.listWidget2.clear()
+        self.listWidget2.addItem("Cell ID")
+        self.listWidget2.addItem("Cell RNC")
+        self.listWidget2.addItem("Cell Services")
+        self.listWidget2.addItem("Cell Status")   
+        self.listWidget2.addItem("GPS Position")
+        self.listWidget2.addItem("Internal IP")
+        self.listWidget2.addItem("Phone signal")
+        self.listWidget2.sortItems()
         
 # Funtion - update GPS - Using lib-location
     def updateGPS(self):
@@ -296,7 +328,22 @@ class Ui_MainWindow(object):
             b.close ()
         elif self.CloseDialog == QtGui.QMessageBox.No:
             print "User pressed 'No' button"
-            
+
+    def updatesound(self):
+
+        bus = dbus.SessionBus()
+        proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+        interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+        interface.Notify('HealthCheck', 0, './healthcheck.png', 'Sound Test', 'Stereo then Mono Test', [], {}, 3000)
+        
+        b = None
+        b = os.popen('pacat --channels=2 /usr/share/sounds/ui-wake_up_tune.wav')
+        b.close ()
+
+        b = None
+        b = os.popen('pacat --channels=1 /usr/share/sounds/ui-wake_up_tune.wav')
+        b.close ()
+              
         
         
         
@@ -410,8 +457,7 @@ class Ui_MainWindow(object):
         self.listWidget.addItem("System Locale \t\t" + gc.strip())
 
         gd = os.popen('cat /var/lib/dsme/boot_count').read()
-        gd = gd.strip()        
-        self.listWidget.addItem("Boot Count \t\t\t" + gd.strip())
+        gd = gd.strip()
 
         ge = os.popen('cat /sys/class/i2c-adapter/i2c-2/2-0063/power_level').read()
         ge = ge.strip()
@@ -643,7 +689,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.2-3", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.2-4", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
